*[API]: Application Programming Interface
*[CLI]: Command Line Interface
*[JSON]: JavaScript Object Notation
*[AWS]: Amazon Web Services
*[GCP]: Google Cloud Platform
*[ELK]: Elasticsearch, Logstash, Kibana
*[ISO]: International Organization for Standardization
